import { ORDER_STATUS } from "@/common/enum"
import { formatHashTag, formatPriceDiv } from "@/common/fotmat"
import { View } from "@tarojs/components"
import { memo, useCallback, useMemo } from "react"
import EstimatedAmount from "../estimatedAmount"
import styles  from './index.module.scss'

type OrderParam = {
    estimate_amount: number, //预估金额
    list: any[], 
    sale_mode: number,
    sale_mode_name: string,
    unit: string,
    total_colors: number,
    total_fabrics: number,
    total_number: number,
    status: number, //订单状态
    total_sale_price: number, //销售金额
    total_should_collect_money: number, //应收金额
    total_weight_error_discount: number, //空差优惠
    the_previous_status: number, //取消订单时的订单状态
    actual_amount: number //实付金额
}

type Param = {
    order: OrderParam,
    comfirm?: boolean //是否是确认订单页面使用
}

export default memo(({order, comfirm = false}:Param) => {
    //对应数量
    const formatCount = useCallback((item) => {
        return order?.sale_mode == 0? item.roll : Number(item.length / 100)
    }, [order])
    //对应单价
    const standardPrice = useCallback(price => {
        return formatPriceDiv(price).toLocaleString() + '/' + (order?.sale_mode == 1?'m':'kg')
    }, [order])

    //数量格式
    const numText = useMemo(() => {
        if(order)
            return `${order?.total_fabrics}种面料，${order?.total_colors}种颜色，共${order?.total_number}${order?.unit}`
    }, [order])

    const {
        SaleOrderStatusBooking, // 待接单
        SaleOrderStatusArranging, // 配布中
        SaleOrderStatusArranged, // 已配布
        SaleOrderStatusWaitingPayment, // 待付款
        SaleOrderStatusWaitingDelivery, // 待发货
        SaleOrderStatusWaitingReceipt, // 待收货
        SaleOrderStatusAlreadyReceipt, // 已收货
        SaleOrderStatusComplete, // 已完成
        SaleOrderStatusRefund, // 已退款
        SaleOrderStatusCancel, // 已取消
    } = ORDER_STATUS

    //金额列表枚举
    const priceList = [
        {
            id:1,
            value:[SaleOrderStatusBooking.value, SaleOrderStatusArranging.value],
            label:'预估金额',
            field: 'estimate_amount'
        },
        {
            id:2,
            value:[SaleOrderStatusArranged.value, SaleOrderStatusWaitingPayment.value, SaleOrderStatusWaitingDelivery.value, SaleOrderStatusWaitingReceipt.value, SaleOrderStatusAlreadyReceipt.value, SaleOrderStatusComplete.value, SaleOrderStatusRefund.value, SaleOrderStatusCancel.value],
            label:'合计金额',
            field: 'total_sale_price'
        },
        {
            id:3,
            value:[SaleOrderStatusWaitingPayment.value, SaleOrderStatusWaitingDelivery.value, SaleOrderStatusWaitingReceipt.value, SaleOrderStatusAlreadyReceipt.value, SaleOrderStatusComplete.value, SaleOrderStatusRefund.value, SaleOrderStatusCancel.value],
            label:'空差优惠',
            field: 'total_weight_error_discount'
        },
        {
            id:4,
            value:[ SaleOrderStatusWaitingPayment.value],
            label:'应付金额',
            field: 'total_should_collect_money'
        },
        {
            id:5,
            value:[SaleOrderStatusWaitingDelivery.value, SaleOrderStatusWaitingReceipt.value, SaleOrderStatusAlreadyReceipt.value, SaleOrderStatusComplete.value, SaleOrderStatusRefund.value, SaleOrderStatusCancel.value],
            label:'实付金额',
            field: 'actual_amount'
        }
    ]   

    //是否显示价格
    const showPrice = useCallback((priceInfo, status) => {
        return priceInfo.value.includes(status)
    }, [order])

    const priceConDom = useMemo(() => {
        if(!order) return
        //确认订单
        if(comfirm == true) {
            return <EstimatedAmount  number={formatPriceDiv(order.estimate_amount)} title="预估金额" />
        } 
        //订单为取消订单状态
        if(order?.status == SaleOrderStatusCancel.value) {
            return (
                <>
                    {
                        priceList.map(item => {
                          return <>{showPrice(item, order?.the_previous_status)&&<EstimatedAmount key={item.id} number={formatPriceDiv(order[item.field])} title={item.label} />}</>
                        })
                    }
                </>
            )
        } else {
            return (
                <>
                    {
                        priceList.map(item => {
                          return <>{showPrice(item, order?.status)&&<EstimatedAmount key={item.id} number={formatPriceDiv(order[item.field])} title={item.label} />}</>
                        })
                    }
                </>
            )
        }   
    }, [order])
    
    return (
        <>
            <View className={styles.orders_list_title}>{numText}</View>
            <View className={styles.orders_list_con}>
                {
                    order?.list?.map(item => {
                        return <View key={item.product_code} className={styles.order_list}>
                            <View className={styles.order_list_title}>
                                <View className={styles.tag}>{order.sale_mode_name}</View>
                                <View className={styles.title}>{formatHashTag(item.code, item.name)}</View>
                                <View className={styles.num}>共{item?.product_colors.length}种</View>
                            </View>
                            <View className={styles.order_list_scroll}>
                                {item?.product_colors?.map(colorItem => {
                                    return <View key={colorItem.id} className={styles.order_list_item}>
                                        <View className={styles.order_list_item_img}></View>
                                        <View className={styles.order_list_item_con}>
                                            <View className={styles.order_list_item_des}>
                                                <View className={styles.order_list_item_title}>{colorItem.code + ' ' + colorItem.name}</View>
                                                <View className={styles.order_list_item_price}>¥{standardPrice(colorItem.sale_price)}</View>
                                            </View>
                                            <View className={styles.order_list_item_count}>
                                                <View className={styles.count_num}>×{formatCount(colorItem)}<text>{order.unit}</text></View>
                                                <View className={styles.count_price}><text>¥</text>{formatPriceDiv(colorItem.estimate_amount).toLocaleString()}</View>
                                            </View>
                                        </View>
                                    </View>
                                })}
                            </View>
                        </View>
                    })
                }
                <View className={styles.order_estimated_amount}>
                    {priceConDom}     
                </View>
            </View>
        </>
    )
})